@@ -1,3 +1,3 @@
 from holour.json_handler import json_encode, json_decode
-from holour.logging import setup_log
+from holour.logging import setup_log, get_format
 from holour.config import load_configuration
