@@ -224,6 +224,13 @@ class Poses:
     def add(self, pose: Pose):
         self.poses.append(pose)
 
+    def convert_and_add_unity_pose(self, pose: Pose):
+        self.poses.append(Pose(
+            Vector3(pose.position.x, pose.position.z, pose.position.y),
+            pose.rotation,  # TODO: add some conversion?
+            pose.name
+        ))
+
     def __eq__(self, other: object) -> bool:
         if isinstance(other, Poses):
             return other.connected == self.connected and other.poses == self.poses
