@@ -31,3 +31,8 @@ class Test(TestCase):
         assert ft1 == ft2
         assert ft1 != ft3
         assert ft1 != "hej"
+
+    def test_ft_repr(self):
+        ft = ForceTorque(Vector3(1, 2, 3), Vector3(-1.1, -1.2, 1.3))
+        expected, got = f'x=1', f'{ft}'
+        assert expected in got, f"Expected {expected} in got: {got}"
